@@ -18,7 +18,6 @@ from vfscript.training.utils import resolve_input_params_path
 
 class AtomicGraphGenerator:
     def __init__(self, json_params_path: str = None):
-        # --- Parámetros de input_params.json -------------
         if json_params_path is None:
             json_params_path = resolve_input_params_path("input_params.json")
         cfg = json.load(open(json_params_path))["CONFIG"][0]
@@ -28,44 +27,45 @@ class AtomicGraphGenerator:
         self.smoothing = cfg['smoothing_level_training']
         self.iterations= cfg['max_graph_variations']
         self.max_nodes = cfg['max_graph_size']
-        # -------------------------------------------------
+       
 
         self.pipeline = import_file(self.input_path, multiple_frames=True)
 
-        # Prepara JSON
+       
         self.records = []
 
-        # Rutas y header
+        
         self.csv_path = "outputs/csv/finger_data.csv"
         os.makedirs(os.path.dirname(self.csv_path), exist_ok=True)
 
         header = [
-            "vacancys",  # tú pusiste 'length', pon aquí el nombre real
+            "vacancys",  
             "N", "mean", "std",
             "skewness", "kurtosis", "Q1", "median", "Q3", "IQR"
         ] + [f"hist_bin_{i}" for i in range(1,11)]
 
-        # Sólo escribir header si el archivo NO existe o está vacío
         if not os.path.exists(self.csv_path) or os.path.getsize(self.csv_path) == 0:
             with open(self.csv_path, 'w', newline='', encoding='utf-8') as csvfile:
                 writer = csv.writer(csvfile)
                 writer.writerow(header)
     def run(self):
-        for _ in range(self.iterations):
-            for length in range(2, self.max_nodes + 1):
-                ids, _ = self._generate_graph(length)
+        for variation_idx in range(self.iterations):
+            for graph_size in range(1, self.max_nodes + 1):
+                ids, _ = self._generate_graph(graph_size)
                 expr = " || ".join(f"ParticleIdentifier=={pid}" for pid in ids)
 
-                # 1) exportar dump y calcular área/volumen
-                area, volume, count, dump_path = self._export_and_dump(expr)
-
-                # 2) extraer normas y estadísticas
+                area, volume, count, dump_path = self._export_and_dump(
+                    expr,
+                    graph_size,
+                    variation_idx
+                )
+                
                 proc = DumpProcessor(dump_path)
                 proc.read_and_translate()
                 proc.compute_norms()
                 stats = StatisticsCalculator.compute_statistics(proc.norms)
 
-                # 3) agregar al JSON interno
+              
                 rec = {
                     "surface_area": area,
                     "filled_volume": volume,
@@ -75,9 +75,9 @@ class AtomicGraphGenerator:
                 }
                 self.records.append(rec)
 
-                # 4) escribir línea en el CSV
+                
                 row = [
-                    length,
+                    len(ids),
                     stats['N'],
                     stats['mean'],
                     stats['std'],
@@ -92,7 +92,7 @@ class AtomicGraphGenerator:
                     writer = csv.writer(csvfile)
                     writer.writerow(row)
 
-        # Guardar JSON completo
+    
         os.makedirs("outputs/json", exist_ok=True)
         with open("outputs/json/training_graph.json", "w", encoding='utf-8') as f:
             json.dump(self.records, f, indent=4)
@@ -123,7 +123,7 @@ class AtomicGraphGenerator:
 
         return ids, coords
 
-    def _export_and_dump(self, expr: str):
+    def _export_and_dump(self, expr: str,i: int,a:int):
         p = copy.deepcopy(self.pipeline)
         p.modifiers.append(ExpressionSelectionModifier(expression=expr))
         p.modifiers.append(DeleteSelectedModifier())
@@ -148,7 +148,7 @@ class AtomicGraphGenerator:
 
         dump_dir  = "outputs/dump"
         os.makedirs(dump_dir, exist_ok=True)
-        dump_path = os.path.join(dump_dir, f"graph_{count}.dump")
+        dump_path = os.path.join(dump_dir, f"graph_{i}_{a}.dump")
         export_file(
             p, dump_path, 'lammps/dump',
             columns=[
